<template>
  <div class="mod-config">
    <basic-container>
      <el-form :inline="true" :model="dataForm" @keyup.enter.native="getDataList()">
        <el-form-item>
          <el-button v-if="permissions.process_photosevidence_add" icon="el-icon-plus" type="primary" @click="addOrUpdateHandle()">新增</el-button>
        </el-form-item>
      </el-form>

      <div class="avue-crud">
        <el-table
                :data="dataList"
                border
                v-loading="dataListLoading">
            <el-table-column
              fixed="left"
                    prop="processAjApprovalName"
                    header-align="center"
                    align="center"
                    label="案件名">
            </el-table-column>
            <el-table-column
                    prop="subjectType"
                    header-align="center"
                    align="center"
                    label="主体类别">
            </el-table-column>
            <el-table-column
                    prop="subjectName"
                    header-align="center"
                    align="center"
                    label="主体名称">
            </el-table-column>
            <el-table-column
                    prop="code"
                    header-align="center"
                    align="center"
                    label="照片编号">
            </el-table-column>
            <el-table-column
                    prop="description"
                    header-align="center"
                    align="center"
                    label="事项说明">
            </el-table-column>
            <el-table-column
                    prop="takeTime"
                    header-align="center"
                    align="center"
                    label="拍摄时间">
            </el-table-column>
            <el-table-column
                    prop="takeAddr"
                    header-align="center"
                    align="center"
                    label="拍摄地点">
            </el-table-column>
            <el-table-column
                    prop="officer"
                    header-align="center"
                    align="center"
                    label="执法人员">
            </el-table-column>
            <el-table-column
                    prop="clientSignImg"
                    header-align="center"
                    align="center"
                    label="当事人签名">
            </el-table-column>
            <el-table-column
                    prop="photosAddr"
                    header-align="center"
                    align="center"
                    label="照片地址，多个逗号分隔">
            </el-table-column>
            <el-table-column
              fixed="right"
                  header-align="center"
                  align="center"
                  label="操作">
            <template slot-scope="scope">
              <el-button v-if="permissions.process_photosevidence_edit" type="text" size="small" icon="el-icon-edit" @click="addOrUpdateHandle(scope.row.id)">修改</el-button>
              <el-button v-if="permissions.process_photosevidence_del" type="text" size="small" icon="el-icon-delete" @click="deleteHandle(scope.row.id)">删除</el-button>
              <el-button v-if="permissions.process_photosevidence_wordpdf" type="text" size="small" icon="el-icon-download" @click="download(scope.row.id)">下载</el-button>
              <el-button v-if="permissions.process_photosevidence_wordpdf" type="text" size="small" icon="el-icon-view" @click="viewPdf(scope.row.id)">预览</el-button>
            </template>
          </el-table-column>
        </el-table>
      </div>

      <div class="avue-crud__pagination">
        <el-pagination
                @size-change="sizeChangeHandle"
                @current-change="currentChangeHandle"
                :current-page="pageIndex"
                :page-sizes="[10, 20, 50, 100]"
                :page-size="pageSize"
                :total="totalPage"
                background
                layout="total, sizes, prev, pager, next, jumper">
        </el-pagination>
      </div>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form v-if="addOrUpdateVisible" ref="addOrUpdate" @refreshDataList="getDataList"></table-form>
    </basic-container>
  </div>
</template>

<script>
  import {fetchList, delObj, createWord} from '@/api/process/photosevidence'
  import {wordToPdf, download, viewPdf} from '@/api/process/wordcommon'
  import TableForm from './photosevidence-form'
  import {mapGetters} from 'vuex'
  export default {
    data () {
      return {
        dataForm: {
          key: ''
        },
        dataList: [],
        pageIndex: 1,
        pageSize: 10,
        totalPage: 0,
        dataListLoading: false,
        addOrUpdateVisible: false
      }
    },
    components: {
      TableForm
    },
    created () {
      this.getDataList()
    },
    computed: {
      ...mapGetters(['permissions'])
    },
    methods: {
      // 获取数据列表
      getDataList () {
        this.dataListLoading = true
        fetchList(Object.assign({
          current: this.pageIndex,
          size: this.pageSize
        })).then(response => {
          this.dataList = response.data.data.records
          this.totalPage = response.data.data.total
        })
        this.dataListLoading = false
      },
      // 每页数
      sizeChangeHandle (val) {
        this.pageSize = val
        this.pageIndex = 1
        this.getDataList()
      },
      // 当前页
      currentChangeHandle (val) {
        this.pageIndex = val
        this.getDataList()
      },
      // 新增 / 修改
      addOrUpdateHandle (id) {
        this.addOrUpdateVisible = true
        this.$nextTick(() => {
          this.$refs.addOrUpdate.init(id)
        })
      },
      // 删除
      deleteHandle (id) {
        this.$confirm('是否确认删除ID为' + id, '提示', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          type: 'warning'
        }).then(function () {
          return delObj(id)
        }).then(data => {
          this.$message.success('删除成功')
          this.getDataList()
        })
      },
      //下载word
      download(id){
        createWord(id).then(res=>{
          if(res.data.code == 0){
            download(res.data.data)
          }
        })
      },

      //预览pdf
      viewPdf(id){
        createWord(id).then(res=>{
          if(res.data.code == 0){
            wordToPdf(res.data.data).then(res1=>{
              viewPdf(res1.data.data)
            })
          }
        })
      }
    }
  }
</script>
